@@ -243,11 +243,15 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 		param = (const gchar *) l->data;
 		if (param) {
 			GHashTable *values;
+			gchar *title;
 
 			box = gnome_db_new_hbox_widget (TRUE, 0);
-			label = gnome_db_new_label_widget (param);
+			title = g_strdup_printf ("_%s:", param);
+			label = gnome_db_new_label_widget (title);
+			g_free (title);
 			gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
 			widget = gnome_db_new_entry_widget (0, TRUE);
+			gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 			if (!g_strcasecmp (param, "PASSWORD"))
 				gtk_entry_set_visibility (GTK_ENTRY (widget), FALSE);
 
@@ -280,7 +284,7 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 	gtk_box_pack_start (GTK_BOX (druid->priv->provider_container),
 			    druid->priv->provider_detail, TRUE, TRUE, 0);
 
-	gda_config_free_provider_info (prov_info);
+	gda_provider_info_free (prov_info);
 
 	return FALSE;
 }
@@ -397,36 +401,36 @@ gnome_db_dsn_config_druid_init (GnomeDbDsnConfigDruid *druid,
 		  "items for your new data source. Some of them (description,\n"
 		  "username) are optional, whereas the others are mandatory.\n"
 		  "If you don't know which provider to use, just select\n"
-		  "the default one"));
+		  "the default one."));
 	gnome_druid_page_standard_append_item (
 		GNOME_DRUID_PAGE_STANDARD (druid->priv->general_page), NULL, label, NULL);
 
 	druid->priv->general_name = gnome_db_new_entry_widget (0, TRUE);
 	gnome_druid_page_standard_append_item (
 		GNOME_DRUID_PAGE_STANDARD (druid->priv->general_page),
-		_("Data source name"), druid->priv->general_name, NULL);
+		_("Data source _name:"), druid->priv->general_name, NULL);
 
 	druid->priv->general_provider = gnome_db_provider_selector_new ();
 	gtk_widget_show (druid->priv->general_provider);
 	gnome_druid_page_standard_append_item (
 		GNOME_DRUID_PAGE_STANDARD (druid->priv->general_page),
-		_("Provider"), druid->priv->general_provider, NULL);
+		_("_Provider:"), druid->priv->general_provider, NULL);
 
 	druid->priv->general_description = gnome_db_new_entry_widget (0, TRUE);
 	gnome_druid_page_standard_append_item (
 		GNOME_DRUID_PAGE_STANDARD (druid->priv->general_page),
-		_("Description"), druid->priv->general_description, NULL);
+		_("_Description:"), druid->priv->general_description, NULL);
 
 	druid->priv->general_username = gnome_db_new_entry_widget (0, TRUE);
 	gnome_druid_page_standard_append_item (
 		GNOME_DRUID_PAGE_STANDARD (druid->priv->general_page),
-		_("Username"), druid->priv->general_username, NULL);
+		_("_Username:"), druid->priv->general_username, NULL);
 
 	druid->priv->general_password = gnome_db_new_entry_widget (0, TRUE);
 	gtk_entry_set_visibility (GTK_ENTRY (druid->priv->general_password), FALSE);
 	gnome_druid_page_standard_append_item (
 		GNOME_DRUID_PAGE_STANDARD (druid->priv->general_page),
-		_("Password"), druid->priv->general_password, NULL);
+		_("P_assword:"), druid->priv->general_password, NULL);
 
 	gtk_widget_show (druid->priv->general_page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
@@ -446,7 +450,7 @@ gnome_db_dsn_config_druid_init (GnomeDbDsnConfigDruid *druid,
 		_("The following fields represent the information needed by the\n"
 		  "provider you selected in the previous page to open a given\n"
 		  "connection. This information is provider-specific, so check\n"
-		  "the manual for more information"));
+		  "the manual for more information."));
 	gnome_druid_page_standard_append_item (
 		GNOME_DRUID_PAGE_STANDARD (druid->priv->provider_page), NULL, label, NULL);
 
@@ -470,7 +474,7 @@ gnome_db_dsn_config_druid_init (GnomeDbDsnConfigDruid *druid,
 		_("All information needed to create a new data source\n"
 		  "has been retrieved. Now, press 'Apply' to close\n"
 		  "this dialog. To open your newly created data source,\n"
-		  "just select it when asked for a data source"),
+		  "just select it when asked for a data source."),
 		  druid->priv->logo, NULL, NULL);
 	gtk_widget_show (druid->priv->end_page);
 	gnome_druid_append_page (GNOME_DRUID (druid),
