@@ -20,6 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <gtk/gtklabel.h>
 #include <gtk/gtktable.h>
 #include <libgnomedb/gnome-db-dsn-config.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
@@ -100,55 +101,62 @@ gnome_db_dsn_config_init (GnomeDbDsnConfig *config, GnomeDbDsnConfigClass *klass
 	table = gnome_db_new_table_widget (6, 3, FALSE);
 	gtk_box_pack_start (GTK_BOX (config), table, TRUE, TRUE, 0);
 
-	label = gnome_db_new_label_widget (_("Data source name"));
+	label = gnome_db_new_label_widget (_("Data source _name:"));
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 	config->priv->wname = gnome_db_new_entry_widget (0, TRUE);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), config->priv->wname);
+	gtk_widget_set_sensitive (config->priv->wname, FALSE); /* FIXME */
 	g_signal_connect (G_OBJECT (config->priv->wname), "changed",
 			  G_CALLBACK (field_changed_cb), config);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wname, 1, 2, 0, 1,
-			  GTK_FILL, GTK_FILL, 0, 0);
+			  GTK_FILL|GTK_EXPAND, GTK_FILL, 0, 0);
 
-	label = gnome_db_new_label_widget (_("Provider"));
+	label = gnome_db_new_label_widget (_("_Provider:"));
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 	config->priv->wprovider = gnome_db_provider_selector_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), config->priv->wprovider);
 	gtk_widget_show (config->priv->wprovider);
 	g_signal_connect (G_OBJECT (config->priv->wprovider), "changed",
 			  G_CALLBACK (field_changed_cb), config);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wprovider, 1, 2, 1, 2,
-			  GTK_FILL, GTK_FILL, 0, 0);
+			  GTK_FILL|GTK_EXPAND, GTK_FILL, 0, 0);
 
-	label = gnome_db_new_label_widget (_("Connection string"));
+	label = gnome_db_new_label_widget (_("Connection _string:"));
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 	config->priv->wstring = gnome_db_new_entry_widget (0, TRUE);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), config->priv->wstring);
 	g_signal_connect (G_OBJECT (config->priv->wstring), "changed",
 			  G_CALLBACK (field_changed_cb), config);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wstring, 1, 2, 2, 3,
-			  GTK_FILL, GTK_FILL, 0, 0);
+			  GTK_FILL|GTK_EXPAND, GTK_FILL, 0, 0);
 
-	label = gnome_db_new_label_widget (_("Description"));
+	label = gnome_db_new_label_widget (_("_Description:"));
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4, GTK_FILL, GTK_FILL, 0, 0);
 	config->priv->wdesc = gnome_db_new_entry_widget (0, TRUE);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), config->priv->wdesc);
 	g_signal_connect (G_OBJECT (config->priv->wdesc), "changed",
 			  G_CALLBACK (field_changed_cb), config);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wdesc, 1, 2, 3, 4,
-			  GTK_FILL, GTK_FILL, 0, 0);
+			  GTK_FILL|GTK_EXPAND, GTK_FILL, 0, 0);
 
-	label = gnome_db_new_label_widget (_("Username"));
+	label = gnome_db_new_label_widget (_("_Username:"));
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5, GTK_FILL, GTK_FILL, 0, 0);
 	config->priv->wuser = gnome_db_new_entry_widget (0, TRUE);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), config->priv->wuser);
 	g_signal_connect (G_OBJECT (config->priv->wuser), "changed",
 			  G_CALLBACK (field_changed_cb), config);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wuser, 1, 2, 4, 5,
-			  GTK_FILL, GTK_FILL, 0, 0);
+			  GTK_FILL|GTK_EXPAND, GTK_FILL, 0, 0);
 
-	label = gnome_db_new_label_widget (_("Password"));
+	label = gnome_db_new_label_widget (_("P_assword:"));
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6, GTK_FILL, GTK_FILL, 0, 0);
 	config->priv->wpassword = gnome_db_new_entry_widget (0, TRUE);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), config->priv->wpassword);
 	gtk_entry_set_visibility (GTK_ENTRY (config->priv->wpassword), FALSE);
 	g_signal_connect (G_OBJECT (config->priv->wpassword), "changed",
 			  G_CALLBACK (field_changed_cb), config);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wpassword, 1, 2, 5, 6,
-			  GTK_FILL, GTK_FILL, 0, 0);
+			  GTK_FILL|GTK_EXPAND, GTK_FILL, 0, 0);
 }
 
 static void
