@@ -23,14 +23,16 @@
 #include <string.h>
 #include <glib/gfileutils.h>
 #include <libgda/gda-util.h>
+#include <gtk/gtkcheckmenuitem.h>
 #include <gtk/gtkdialog.h>
+#include <gtk/gtklabel.h>
 #include <gtk/gtkradiobutton.h>
+#include <gtk/gtkseparatormenuitem.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtkwindow.h>
-#include <gtk/gtkimagemenuitem.h>
 #include <gobject/gmarshal.h>
 #include <libgnomedb/gnome-db-form.h>
 #include <libgnomedb/gnome-db-gray-bar.h>
@@ -129,19 +131,49 @@ menu_describe_cb (GtkWidget *widget, gpointer user_data)
 }
 #endif
 
-static void
-menu_hide_columns_cb (GtkWidget *widget, gpointer user_data)
+static gboolean
+confirm_overwrite (GtkWindow *parent, const gchar *path)
 {
-	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
+	GtkWidget *dialog, *button;
+	gboolean yes;
+	gchar *msg;
 
-	g_return_if_fail (GNOME_DB_IS_GRID (grid));
-	gnome_db_grid_hide_column_titles (grid);
+	msg = g_strdup_printf (_("File '%s' already exists.\n"
+				 "Do you want to overwrite it?"), path);
+
+	/* build the dialog */
+	dialog = gnome_db_new_alert (
+		NULL,
+		GTK_MESSAGE_QUESTION,
+		msg,
+		_("If you choose yes, the contents will be lost."));
+	button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
+				      button,
+				      GTK_RESPONSE_NO);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
+				      gtk_button_new_from_stock (GTK_STOCK_YES),
+				      GTK_RESPONSE_YES);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
+					 GTK_RESPONSE_NO);
+
+	/* run the dialog */
+	gtk_widget_show_all (dialog);
+	yes = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
+
+	/* free memory */
+	gtk_widget_destroy (dialog);
+	g_free (msg);
+	return yes;
 }
-
+					    
 #ifdef BUILD_WITH_GNOME
 static void
 save_as_response_cb (GtkDialog *dialog, guint response_id, gpointer user_data)
 {
+	GtkWidget *types;
+	GtkWidget *sel_type;
 	GtkWidget *to_tab;
 	GtkWidget *to_comma;
 	GtkWidget *to_xml;
@@ -152,16 +184,20 @@ save_as_response_cb (GtkDialog *dialog, guint response_id, gpointer user_data)
 		gchar *body;
 		gchar *path;
 
+		types = g_object_get_data (G_OBJECT (dialog), "types");
 		to_tab = g_object_get_data (G_OBJECT (dialog), "to_tab");
 		to_comma = g_object_get_data (G_OBJECT (dialog), "to_comma");
 		to_xml = g_object_get_data (G_OBJECT (dialog), "to_xml");
 		filename = g_object_get_data (G_OBJECT (dialog), "filename");
 
-		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (to_tab)))
+		sel_type = gtk_menu_get_active (
+			GTK_MENU (gtk_option_menu_get_menu (GTK_OPTION_MENU (types))));
+
+		if (sel_type == to_tab)
 			body = gda_data_model_to_tab_separated (grid->priv->model);
-		else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (to_comma)))
+		else if (sel_type == to_comma)
 			body = gda_data_model_to_comma_separated (grid->priv->model);
-		else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (to_xml)))
+		else if (sel_type == to_xml)
 			body = gda_data_model_to_xml (grid->priv->model, TRUE);
 		else
 			body = NULL;
@@ -170,14 +206,11 @@ save_as_response_cb (GtkDialog *dialog, guint response_id, gpointer user_data)
 			path = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY (filename), FALSE);
 			if (path) {
 				if (g_file_test (path, G_FILE_TEST_EXISTS)) {
-					if (!gnome_db_yes_no_dialog (GTK_WIDGET (dialog),
-								     _("File %s already exists\n"
-								       "Do you want to overwrite it?"), path)) {
+					if (!confirm_overwrite (GTK_WINDOW (dialog), path)) {
 						g_free (body);
 						g_free (path);
 						return;
 					}
-					    
 				}
 
 				if (!gda_file_save (path, body, strlen (body))) {
@@ -200,6 +233,13 @@ save_as_response_cb (GtkDialog *dialog, guint response_id, gpointer user_data)
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
+static void
+filename_changed_cb (GtkWidget *widget, GtkDialog *dialog)
+{
+	gboolean ok = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY (widget), FALSE) != NULL;
+	gtk_dialog_set_response_sensitive (dialog, GTK_RESPONSE_OK, ok);
+}
+
 static void
 menu_save_as_cb (GtkWidget *widget, gpointer user_data)
 {
@@ -207,10 +247,10 @@ menu_save_as_cb (GtkWidget *widget, gpointer user_data)
 	GtkWidget *table;
 	GtkWidget *label;
 	GtkWidget *filename;
+	GtkWidget *types;
 	GtkWidget *to_tab;
 	GtkWidget *to_comma;
 	GtkWidget *to_xml;
-	GdkPixbuf *icon;
 	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
@@ -218,46 +258,49 @@ menu_save_as_cb (GtkWidget *widget, gpointer user_data)
 
 	/* create dialog box */
 	dialog = gtk_dialog_new_with_buttons (
-		_("Save as"),
+		_("Saving Model"),
 		GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (grid))), 0,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		GTK_STOCK_OK, GTK_RESPONSE_OK,
+		GTK_STOCK_SAVE, GTK_RESPONSE_OK,
 		NULL);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, FALSE);
 
-	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
-	if (icon) {
-		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
-		g_object_unref (icon);
-	}
-
-	table = gnome_db_new_table_widget (6, 2, FALSE);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, TRUE, TRUE, 0);
-
-	label = gnome_db_new_label_widget (_("Save to"));
+	table = gnome_db_new_table_widget (2, 2, FALSE);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, TRUE, TRUE, 6);
+	label = gtk_label_new_with_mnemonic (_("File _name:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
-	filename = gnome_db_new_file_entry_widget ("gnome-db-grid-save-as", _("Select File"));
+	filename = gnome_db_new_file_entry_widget ("gnome-db-grid-save-as",
+						   _("Select File"));
+	g_signal_connect (G_OBJECT (filename), "changed",
+			  G_CALLBACK (filename_changed_cb), dialog);
 	g_object_set_data (G_OBJECT (dialog), "filename", filename);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), filename);
 	gtk_table_attach (GTK_TABLE (table), filename, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
 
-	to_tab = gnome_db_new_radio_button_widget (NULL, _("Tab-delimited file"));
+	label = gtk_label_new_with_mnemonic (_("File _type:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
+	types = gnome_db_new_option_menu_widget ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), types);
+	gtk_table_attach (GTK_TABLE (table), types, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
+	g_object_set_data (G_OBJECT (dialog), "types", types);
+	to_tab = gnome_db_option_menu_add_item (GTK_OPTION_MENU (types),
+						_("Tab-delimited"));
 	g_object_set_data (G_OBJECT (dialog), "to_tab", to_tab);
-	gtk_table_attach (GTK_TABLE (table), to_tab, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
-
-	to_comma = gnome_db_new_radio_button_widget (
-		gtk_radio_button_get_group (GTK_RADIO_BUTTON (to_tab)),
-		_("Comma-delimited file"));
+	to_comma = gnome_db_option_menu_add_item (GTK_OPTION_MENU (types),
+						  _("Comma-delimited"));
 	g_object_set_data (G_OBJECT (dialog), "to_comma", to_comma);
-	gtk_table_attach (GTK_TABLE (table), to_comma, 1, 2, 2, 3, GTK_FILL, GTK_FILL, 2, 2);
-
-	to_xml = gnome_db_new_radio_button_widget (
-		gtk_radio_button_get_group (GTK_RADIO_BUTTON (to_tab)),
-		_("XML file"));
+	to_xml = gnome_db_option_menu_add_item (GTK_OPTION_MENU (types),
+						_("XML"));
+	gnome_db_option_menu_set_selection (GTK_OPTION_MENU (types), _("XML"));
 	g_object_set_data (G_OBJECT (dialog), "to_xml", to_xml);
-	gtk_table_attach (GTK_TABLE (table), to_xml, 1, 2, 3, 4, GTK_FILL, GTK_FILL, 2, 2);
 
 	/* run the dialog */
 	g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (save_as_response_cb), grid);
-	gtk_widget_show (dialog);
+	gtk_widget_show_all (dialog);
 }
 #endif
 
@@ -273,10 +316,18 @@ menu_select_all_cb (GtkWidget *widget, gpointer user_data)
 static void
 menu_show_columns_cb (GtkWidget *widget, gpointer user_data)
 {
-	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
+	GnomeDbGrid *grid;
+	GtkCheckMenuItem *item;
+
+	grid = (GnomeDbGrid *) user_data;
+	item = (GtkCheckMenuItem *) widget;
 
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
-	gnome_db_grid_show_column_titles (grid);
+	g_return_if_fail (GTK_IS_CHECK_MENU_ITEM (item));
+
+	gnome_db_grid_set_column_titles_visible (
+		grid, 
+		gtk_check_menu_item_get_active (item));
 }
 
 static void
@@ -288,6 +339,7 @@ menu_unselect_all_cb (GtkWidget *widget, gpointer user_data)
 	gnome_db_grid_unselect_all (grid);
 }
 
+#if 0
 static void
 menu_view_detail_cb (GtkWidget *widget, gpointer user_data)
 {
@@ -321,6 +373,7 @@ menu_view_detail_cb (GtkWidget *widget, gpointer user_data)
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
+#endif
 
 static void
 model_row_removed_cb (GdaDataModel *model, gint row, gpointer user_data)
@@ -343,50 +396,57 @@ model_row_removed_cb (GdaDataModel *model, gint row, gpointer user_data)
 	}
 }
 
-static void
-add_popup_menu_item (GtkMenu *menu, const gchar *label, gboolean pixmap, GCallback cb_func, gpointer user_data)
-{
-	GtkWidget *item;
-
-	if (pixmap)
-		item = gtk_image_menu_item_new_from_stock (label, NULL);
-	else
-		item = gtk_menu_item_new_with_label (label);
-	g_signal_connect (G_OBJECT (item), "activate",
-			  G_CALLBACK (cb_func), user_data);
-	gtk_menu_append (GTK_MENU (menu), item);
-	gtk_widget_show (item);
-
-}
-
 static gint
 popup_button_pressed_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
 	GtkWidget *menu;
 	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
 
-	g_return_if_fail (GNOME_DB_IS_GRID (grid));
-
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), FALSE);
+	
 	if (event->button != 3)
 		return FALSE;
 
 	/* create the menu */
 	menu = gtk_menu_new ();
-	add_popup_menu_item (GTK_MENU (menu), _("Select All"), FALSE, menu_select_all_cb, grid);
-	add_popup_menu_item (GTK_MENU (menu), _("Clear selection"), FALSE, menu_unselect_all_cb, grid);
-	add_popup_menu_item (GTK_MENU (menu), _("Show columns"), FALSE, menu_show_columns_cb, grid);
-	add_popup_menu_item (GTK_MENU (menu), _("Hide columns"), FALSE, menu_hide_columns_cb, grid);
+	gtk_menu_append (
+		GTK_MENU (menu),
+		gnome_db_new_menu_item (_("Select _All"),
+					FALSE,
+					G_CALLBACK (menu_select_all_cb),
+					grid));	
+	gtk_menu_append (
+		GTK_MENU (menu),
+		gnome_db_new_menu_item (_("_Clear Selection"),
+					FALSE,
+					G_CALLBACK (menu_unselect_all_cb),
+					grid));
+	gtk_menu_append (
+		GTK_MENU (menu),
+		gnome_db_new_check_menu_item (
+			_("Show Column _Titles"),
+			gnome_db_grid_get_column_titles_visible (grid),
+			G_CALLBACK (menu_show_columns_cb),
+			grid));
+
 #ifdef BUILD_WITH_GNOME
-	add_popup_menu_item (GTK_MENU (menu), GTK_STOCK_SAVE_AS, TRUE, menu_save_as_cb, grid);
+	gtk_menu_append (GTK_MENU (menu), gtk_separator_menu_item_new ());
+	gtk_menu_append (
+		GTK_MENU (menu),
+		gnome_db_new_menu_item (GTK_STOCK_SAVE_AS,
+					TRUE,
+				      	G_CALLBACK (menu_save_as_cb),
+					grid));
 #endif
 #if 0
-	add_popup_menu_item (GTK_MENU (menu), _("Describe"), menu_describe_cb, grid);
-	add_popup_menu_item (GTK_MENU (menu), _("View detail..."), menu_view_detail_cb, grid);
+	add_popup_menu_item (GTK_MENU (menu), _("Describe"), G_CALLBACK (menu_describe_cb), grid);
+	add_popup_menu_item (GTK_MENU (menu), _("View detail..."), G_CALLBACK (menu_view_detail_cb), grid);
 #endif
 
 	/* allow listeners to add their custom menu items */
 	g_signal_emit (G_OBJECT (grid), gnome_db_grid_signals[CREATE_POPUP_MENU], 0, GTK_MENU (menu));
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, event->button, event->time);
+	gtk_widget_show_all (menu);
 
 	return TRUE;
 }
@@ -451,10 +511,10 @@ tree_view_row_activated_cb (GtkTreeView *tree_view, GtkTreePath *path,
 
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
 
-	if (!gtk_tree_model_get_iter (gtk_tree_view_get_model (grid->priv->tree_view), &iter, path))
+	if (!gtk_tree_model_get_iter (gtk_tree_view_get_model (GTK_TREE_VIEW (grid->priv->tree_view)), &iter, path))
 		return;
 
-	gtk_tree_model_get (gtk_tree_view_get_model (grid->priv->tree_view), &iter, 0, &info, -1);
+	gtk_tree_model_get (gtk_tree_view_get_model (GTK_TREE_VIEW (grid->priv->tree_view)), &iter, 0, &info, -1);
 	if (!info)
 		return;
 
@@ -660,6 +720,10 @@ gnome_db_grid_get_type (void)
 
 /**
  * gnome_db_grid_new
+ * 
+ * Create a #GnomeDbGrid.
+ *
+ * Returns: a GtkWidget widget.
  */
 GtkWidget *
 gnome_db_grid_new (void)
@@ -672,6 +736,11 @@ gnome_db_grid_new (void)
 
 /**
  * gnome_db_grid_new_with_model
+ * @model: a #GdaDataModel variable.
+ * 
+ * Create a #GnomeDbGrid with a #GdaDataModel.
+ *
+ * Returns: a GtkWidget widget.
  */
 GtkWidget *
 gnome_db_grid_new_with_model (GdaDataModel *model)
@@ -718,6 +787,52 @@ gnome_db_grid_set_title (GnomeDbGrid *grid, const gchar *title)
 	gnome_db_gray_bar_set_text (GNOME_DB_GRAY_BAR (grid->priv->title), title);
 }
 
+/**
+ * gnome_db_grid_set_column_title
+ * @grid a #GnomeDbGrid widget
+ * @col the number of the column to change the title
+ * @title the new title for this column
+ *
+ * Sets the title for a column
+ */
+void 
+gnome_db_grid_set_column_title (GnomeDbGrid *grid, gint col, const gchar *title)
+{
+	GtkTreeViewColumn *column = NULL;
+	gint number_columns;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+	g_return_if_fail (title != NULL);
+
+	number_columns = gda_data_model_get_n_columns (grid->priv->model);
+	if (col >= 0 && col < number_columns) {
+		column = gtk_tree_view_get_column ( GTK_TREE_VIEW(grid->priv->tree_view), col);
+		gtk_tree_view_column_set_title (column, title);
+	}
+}
+
+/** 
+ * gnome_db_grid_get_column_title
+ * @grid a #GnomeDbGrid widget
+ * @col the number of the column to get the title
+ *
+ * Get the title of a column
+ * Returns: the title of a column.
+ */
+const gchar *
+gnome_db_grid_get_column_title (GnomeDbGrid *grid, gint col)
+{
+	GtkTreeViewColumn *column = NULL;
+	gchar *title = NULL;
+
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), NULL);
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW (grid->priv->tree_view), col);
+	title = gtk_tree_view_column_get_title (column);
+
+	return title;
+}
+
+
 /**
  * gnome_db_grid_get_show_title
  * @grid: a #GnomeDbGrid widget.
@@ -821,6 +936,11 @@ gnome_db_grid_get_show_title_icon (GnomeDbGrid *grid)
 
 /**
  * gnome_db_grid_get_model
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Retrieve the #GdaDataModel associated with this #GnomeDbGrid.
+ * 
+ * Returns: a #GdaDataModel widget.
  */
 GdaDataModel *
 gnome_db_grid_get_model (GnomeDbGrid *grid)
@@ -836,6 +956,10 @@ dummy_remove_hash (gpointer key, gpointer value, gpointer user_data)
 
 /**
  * gnome_db_grid_set_model
+ * @grid: a #GnomeDbGrid widget.
+ * @model: a #GdaDataModel widget.
+ *
+ * Set the new model for the given grid.
  */
 void
 gnome_db_grid_set_model (GnomeDbGrid *grid, GdaDataModel *model)
@@ -938,6 +1062,9 @@ gnome_db_grid_foreach_selected (GnomeDbGrid *grid,
 
 /**
  * gnome_db_grid_select_all
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Select all rows in the #GnomeDbGrid widget.
  */
 void
 gnome_db_grid_select_all (GnomeDbGrid *grid)
@@ -953,6 +1080,9 @@ gnome_db_grid_select_all (GnomeDbGrid *grid)
 
 /**
  * gnome_db_grid_unselect_all
+ * @grid: a #GnomeDbGrid widget.
+ * 
+ * Unselect all rows of the #GnomeDbGrid widget.
  */
 void
 gnome_db_grid_unselect_all (GnomeDbGrid *grid)
@@ -967,6 +1097,11 @@ gnome_db_grid_unselect_all (GnomeDbGrid *grid)
 
 /**
  * gnome_db_grid_get_selection_mode
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Retrieve the selection mode of a #GnomeDbGrid widget.
+ *
+ * Returns: a GtkSelectionMode widget.
  */
 GtkSelectionMode
 gnome_db_grid_get_selection_mode (GnomeDbGrid *grid)
@@ -981,6 +1116,10 @@ gnome_db_grid_get_selection_mode (GnomeDbGrid *grid)
 
 /**
  * gnome_db_set_selection_mode
+ * @grid: a #GnomeDbGrid widget.
+ * @mode: a GtkSelectionMode widget.
+ * 
+ * Set the new selection mode for this #GnomeDbGrid widget.
  */
 void
 gnome_db_grid_set_selection_mode (GnomeDbGrid *grid, GtkSelectionMode mode)
@@ -996,23 +1135,30 @@ gnome_db_grid_set_selection_mode (GnomeDbGrid *grid, GtkSelectionMode mode)
 }
 
 /**
- * gnome_db_grid_hide_column_titles
+ * gnome_db_grid_set_column_titles_visible
+ * @grid: a #GnomeDbGrid widget.
+ * @visible: a gboolean.
+ * 
+ * Hide or Show the titles of the #GnomeDbGrid widget.
  */
 void
-gnome_db_grid_hide_column_titles (GnomeDbGrid *grid)
+gnome_db_grid_set_column_titles_visible (GnomeDbGrid *grid, gboolean visible)
 {
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
-	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (grid->priv->tree_view), FALSE);
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (grid->priv->tree_view), visible);
 }
 
 /**
- * gnome_db_grid_show_column_titles
+ * gnome_db_grid_get_column_titles_visible
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Retrieve a gboolean ( TRUE or FALSE ).
  */
-void
-gnome_db_grid_show_column_titles (GnomeDbGrid *grid)
+gboolean
+gnome_db_grid_get_column_titles_visible (GnomeDbGrid *grid)
 {
-	g_return_if_fail (GNOME_DB_IS_GRID (grid));
-	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (grid->priv->tree_view), TRUE);
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), FALSE);
+	return gtk_tree_view_get_headers_visible (GTK_TREE_VIEW (grid->priv->tree_view));
 }
 
 /**
@@ -1055,6 +1201,53 @@ gnome_db_grid_set_row_data (GnomeDbGrid *grid, gint row, gpointer data)
 		g_hash_table_insert (grid->priv->row_data, GINT_TO_POINTER (row + 1), data);
 }
 
+/**
+ * gnome_db_grid_set_column_visible
+ * @grid: a #GnomeDbGrid widget.
+ * @col: column number.
+ * @visible: a gboolean.
+ * 
+ * Hide or Show the column "col" of the #GnomeDbGrid widget.
+ */
+void
+gnome_db_grid_set_column_visible (GnomeDbGrid *grid, gint col, gboolean visible)
+{
+	GtkTreeViewColumn *column = NULL;
+	gint number_columns;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	number_columns = gda_data_model_get_n_columns (grid->priv->model);
+	if (col >= 0 && col < number_columns) {
+		column = gtk_tree_view_get_column (GTK_TREE_VIEW (grid->priv->tree_view), col);
+		gtk_tree_view_column_set_visible (column, visible);
+	}
+}
+
+/**
+ * gnome_db_grid_get_column_visible
+ * @grid: a #GnomeDbGrid widget.
+ * @col: column number.
+ *
+ * Retrieve a gboolean ( TRUE or FALSE ).
+ */
+gboolean
+gnome_db_grid_get_column_visible (GnomeDbGrid *grid, gint col)
+{
+	GtkTreeViewColumn *column = NULL;
+	gint number_columns;
+
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), FALSE);
+
+	number_columns = gda_data_model_get_n_columns (grid->priv->model);
+	if (col >= 0 && col < number_columns) {
+		column = gtk_tree_view_get_column (GTK_TREE_VIEW (grid->priv->tree_view), col);
+		return gtk_tree_view_column_get_visible (column);
+	}
+
+	return FALSE;
+}
+
 typedef struct {
 	gint row;
 	gpointer search_data;
