@@ -61,8 +61,14 @@ GtkWidget       *gnome_db_grid_new_with_model (GdaDataModel *model);
 
 const gchar     *gnome_db_grid_get_title (GnomeDbGrid *grid);
 void             gnome_db_grid_set_title (GnomeDbGrid *grid, const gchar *title);
+void             gnome_db_grid_set_column_title (GnomeDbGrid *grid, gint col, const gchar *title);
+const gchar     *gnome_db_grid_get_column_title (GnomeDbGrid *grid, gint col);
 gboolean         gnome_db_grid_get_show_title (GnomeDbGrid *grid);
 void             gnome_db_grid_set_show_title (GnomeDbGrid *grid, gboolean show);
+void             gnome_db_grid_set_title_icon_from_file (GnomeDbGrid *grid, const gchar *file);
+void             gnome_db_grid_set_title_icon_from_stock (GnomeDbGrid *grid, const gchar *stock_id, GtkIconSize size);
+void             gnome_db_grid_set_show_title_icon (GnomeDbGrid *grid, gboolean show);
+gboolean         gnome_db_grid_get_show_title_icon (GnomeDbGrid *grid);
 
 GdaDataModel    *gnome_db_grid_get_model (GnomeDbGrid *grid);
 void             gnome_db_grid_set_model (GnomeDbGrid *grid, GdaDataModel *model);
@@ -76,8 +82,14 @@ GtkSelectionMode gnome_db_grid_get_selection_mode (GnomeDbGrid *grid);
 void             gnome_db_grid_set_selection_mode (GnomeDbGrid *grid,
 						   GtkSelectionMode mode);
 
-void             gnome_db_grid_hide_column_titles (GnomeDbGrid *grid);
-void             gnome_db_grid_show_column_titles (GnomeDbGrid *grid);
+void             gnome_db_grid_set_column_titles_visible (GnomeDbGrid *grid, gboolean visible);
+gboolean         gnome_db_grid_get_column_titles_visible (GnomeDbGrid *grid);
+#define gnome_db_grid_show_column_titles(grid) \
+	(gnome_db_grid_set_column_titles_visible (grid, TRUE))
+#define gnome_db_grid_hide_column_titles(grid) \
+	(gnome_db_grid_set_column_titles_visible (grid, FALSE))
+void             gnome_db_grid_set_column_visible (GnomeDbGrid *grid, gint col, gboolean visible);
+gboolean         gnome_db_grid_get_column_visible (GnomeDbGrid *grid, gint col);
 
 gpointer         gnome_db_grid_get_row_data (GnomeDbGrid *grid, gint row);
 void             gnome_db_grid_set_row_data (GnomeDbGrid *grid, gint row, gpointer data);
